OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "Individual" : "Singolo",
    "Group" : "Gruppo",
    "Resource" : "Risorsa",
    "Room" : "Stanza",
    "Unknown" : "Sconosciuto",
    "Required" : "Richiesto",
    "Optional" : "Facoltativo",
    "Does not attend" : "Non partecipa",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sei in un fuso orario sconosciuto ({tz}), ripiego su UTC",
    "Please create a calendar first." : "Crea prima un calendario.",
    "New event" : "Nuovo evento",
    "Attendees" : "Partecipanti",
    "Reminders" : "Promemoria",
    "Repeating" : "Ripetizione",
    "When shared show full event" : "Se condiviso, mostra l'evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "Confirmed" : "Confermato",
    "Tentative" : "Provvisorio",
    "Cancelled" : "Annullati",
    "Please add a title!" : "Aggiungi un titolo!",
    "Please select a calendar!" : "Seleziona un calendario!",
    "Global" : "Globale",
    "None" : "Nessuno",
    "Every day" : "Ogni giorno",
    "Every week" : "Ogni settimana",
    "Every month" : "Ogni mese",
    "Every year" : "Ogni anno",
    "never" : "mai",
    "after" : "dopo",
    "At time of event" : "Al momento dell'evento",
    "5 minutes before" : "5 minuti prima",
    "10 minutes before" : "10 minuti prima",
    "15 minutes before" : "15 minuti prima",
    "30 minutes before" : "30 minuti prima",
    "1 hour before" : "1 ora prima",
    "2 hours before" : "2 ore prima",
    "Custom" : "Personalizzato",
    "Audio" : "Audio",
    "E Mail" : "Posta elettronica",
    "Pop up" : "Finestra a comparsa",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "giorni",
    "week" : "settimana",
    "before" : "prima",
    "start" : "inizia",
    "end" : "finisce",
    "Editing reminders of unknown type not supported." : "La modifica di promemoria di tipo sconosciuto non è supportata.",
    "Week {number} of {year}" : "Settimana {number} del {year}",
    "Successfully imported" : "Importato correttamente",
    "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
    "Partially imported, {n} failures" : "Importato parzialmente, {n} problemi",
    "Audio alarm" : "Avviso sonoro",
    "Pop-up" : "Finestra a comparsa",
    "E-Mail" : "Posta elettronica",
    "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
    "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
    "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
    "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
    "{type} at the event's start" : "{type} all'inizio dell'evento",
    "{type} at the event's end" : "{type} alla fine dell'evento",
    "{type} at {time}" : "{type} alle {time}",
    "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
    "Title of the Event" : "Titolo dell'evento",
    "starts" : "inizia",
    "ends" : "finisce",
    "All day Event" : "Evento di un giorno intero",
    "Delete" : "Elimina",
    "Cancel" : "Annulla",
    "More ..." : "Altro...",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Close" : "Chiudi",
    "Location" : "Posizione",
    "Description" : "Descrizione",
    "Event status" : "Stato dell'evento",
    "Visibility when sharing" : "Visibilità in caso di condivisione",
    "Export" : "Esporta",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Today" : "Oggi",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
    "Share Calendar" : "Condividi calendario",
    "Shared" : "Condiviso",
    "More" : "Altro",
    "Edit" : "Modifica",
    "Link" : "Collegamento",
    "Download" : "Scarica",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "can edit" : "può modificare",
    "group" : "gruppo",
    "New Calendar" : "Nuovo calendario",
    "Subscriptions" : "Sottoscrizioni",
    "New Subscription" : "Nuova sottoscrizione",
    "Url" : "URL",
    "Edit event" : "Modifica evento",
    "Delete Event" : "Elimina evento",
    "Save Event" : "Salva evento",
    "Time" : "Ora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Assoluto",
    "Repeat" : "Ripeti",
    "times every" : "volte ogni",
    "Add" : "Aggiungi",
    "E-Mail address of attendee" : "Indirizzo email del partecipante",
    "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
    "from" : "da",
    "to" : "a",
    "This event's repeating rule is not supported yet." : "Questa regola di ripetizione dell'evento non è ancora supportata.",
    "Support for advanced rules will be added with subsequent updates." : "Il supporto per le regole avanzate sarà aggiunto con aggiornamenti successivi.",
    "Reset repeating rule" : "Ripristina la regola di ripetizione",
    "Repeat every ..." : "Ripeti ogni...",
    "end repeat ..." : "fine della ripetizione...",
    "times" : "volte",
    "Import Calendars" : "Importa calendari",
    "Import canceled" : "Importazione annullata",
    "Analyzing calendar" : "Analisi del calendario",
    "The file contains objects incompatible with the selected calendar" : "Il file contiene oggetti non compatibili con il calendario selezionato",
    "New calendar" : "Nuovo calendario",
    "Import scheduled" : "Importa pianificati",
    "Settings" : "Impostazioni",
    "Skip simple event editor" : "Salta l'editor semplice degli eventi",
    "Import calendar" : "Importa calendario",
    "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
    "Primary CalDAV address" : "Indirizzo CalDAV principale",
    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X"
},
"nplurals=2; plural=(n != 1);");
